#include <libgda/libgda.h>
#include <sql-parser/gda-sql-parser.h>

/*
 * CREATE TABLE bug (id int, name varchar);
 * INSERT INTO bug VALUES (1, NULL);
 */
int main()
{
	gda_init();
	GdaSqlParser *parser;
	GdaStatement *stmt;
	GdaConnection *cnc;
	GError *error = NULL;
	
	cnc = gda_connection_open_from_dsn ("gdapg", "USERNAME=gdauser;PASSWORD=GdaUser",
					    GDA_CONNECTION_OPTIONS_NONE, &error);
	if (!cnc) {
		g_print ("Could not open connection: %s\n",
			 error && error->message ? error->message : "No detail");
		return 1;
	}

	parser = gda_sql_parser_new ();
	stmt = gda_sql_parser_parse_string (parser, "SELECT * FROM bug", NULL, NULL);
	g_assert (stmt);

	GdaDataModel *model;
	model = gda_connection_statement_execute_select (cnc, stmt, NULL, &error);
	if (!model) {
		g_print ("Could not execute SELECT: %s\n",
			 error && error->message ? error->message : "No detail");
		return 1;
	}

	gint nrows, ncols, i, j;
	nrows = gda_data_model_get_n_rows (model);
	ncols = gda_data_model_get_n_columns (model);
	for (i = 0; i < nrows; i++) {
		for (j = 0; j < ncols; j++) {
			const GValue *cvalue;
			cvalue = gda_data_model_get_value_at (model, j, i, &error);
			if (cvalue) {
				gchar *str;
				str = gda_value_stringify (cvalue);
				g_print ("(col=>%d row=>%d) => [%s]\n", j, i, str);
				g_free (str);
			}
			else {
				g_print ("(col=>%d row=>%d) => error [%s]\n", j, i,
					 error && error->message ? error->message : "No detail");
				g_clear_error (&error);
			}
		}
	}

	g_object_unref (cnc);

	return 0;
}
